@@ -1,28 +1,34 @@
 import time
 import os
 import logging
+from typing import Union
 
 import torch
 import torch.distributed as dist
 from aperturedb import Images
 from aperturedb import PyTorchDataset
+from torch.utils.data.dataloader import DataLoader
+from torch.utils.data.dataset import Dataset
 
 logger = logging.getLogger(__name__)
 
 
 class TestTorchDatasets():
-    def validate_dataset(self, dataset):
+    def validate_dataset(self, dataset: Union[DataLoader, Dataset], expected_length):
         start = time.time()
 
+        count = 0
         # Iterate over dataset.
         for img in dataset:
             if len(img[0]) < 0:
                 logger.error("Empty image?")
                 assert True == False
+            count += len(img[1]) if isinstance(dataset, DataLoader) else 1
+        assert count == expected_length
 
-        logger.info("\n")
-        logger.info("Throughput (imgs/s):",
-                    len(dataset) / (time.time() - start))
+        time_taken = time.time() - start
+        if time_taken != 0:
+            logger.info(f"Throughput (imgs/s): {len(dataset) / time_taken}")
 
     def test_omConstraints(self, db, utils, images):
         assert len(images) > 0
@@ -31,8 +37,7 @@ class TestTorchDatasets():
         dataset = PyTorchDataset.ApertureDBDatasetConstraints(
             db, constraints=const)
 
-        assert len(dataset) == utils.count_images()
-        self.validate_dataset(dataset)
+        self.validate_dataset(dataset, utils.count_images())
 
     def test_nativeContraints(self, db, utils, images):
         assert len(images) > 0
@@ -57,10 +62,10 @@ class TestTorchDatasets():
         dataset = PyTorchDataset.ApertureDBDataset(
             db, query, label_prop="license")
 
-        assert len(dataset) == utils.count_images()
-        self.validate_dataset(dataset)
+        self.validate_dataset(dataset, utils.count_images())
 
     def test_datasetWithMultiprocessing(self, db, utils):
+        len_limit = utils.count_images()
         query = [{
             "FindImage": {
                 "constraints": {
@@ -74,7 +79,8 @@ class TestTorchDatasets():
                     }
                 ],
                 "results": {
-                    "list": ["license"]
+                    "list": ["license"],
+                    "limit": len_limit
                 }
             }
         }]
@@ -82,8 +88,7 @@ class TestTorchDatasets():
         dataset = PyTorchDataset.ApertureDBDataset(
             db, query, label_prop="license")
 
-        assert len(dataset) == utils.count_images()
-        self.validate_dataset(dataset)
+        self.validate_dataset(dataset, len_limit)
         # Distributed Data Loader Setup
 
         # Needed for init_process_group
@@ -93,16 +98,16 @@ class TestTorchDatasets():
         dist.init_process_group("gloo", rank=0, world_size=1)
 
         # === Distributed Data Loader Sequential
-
-        data_loader = torch.utils.data.DataLoader(
+        batch_size = 10
+        data_loader = DataLoader(
             dataset,
-            batch_size=10,          # pick random values here to test
+            batch_size=batch_size,          # pick random values here to test
             num_workers=4,          # num_workers > 1 to test multiprocessing works
             pin_memory=True,
             drop_last=True,
         )
 
-        self.validate_dataset(data_loader)
+        self.validate_dataset(data_loader, len_limit)
         # === Distributed Data Loader Shuffler
 
         # This will generate a random sampler, which will make the use
@@ -110,13 +115,13 @@ class TestTorchDatasets():
         sampler     = torch.utils.data.DistributedSampler(
             dataset, shuffle=True)
 
-        data_loader = torch.utils.data.DataLoader(
+        data_loader = DataLoader(
             dataset,
             sampler=sampler,
-            batch_size=10,          # pick random values here to test
+            batch_size=batch_size,          # pick random values here to test
             num_workers=4,          # num_workers > 1 to test multiprocessing works
             pin_memory=True,
             drop_last=True,
         )
 
-        self.validate_dataset(data_loader)
+        self.validate_dataset(data_loader, len_limit)
